aboutsummaryrefslogtreecommitdiff
path: root/src/mlia/devices
diff options
context:
space:
mode:
Diffstat (limited to 'src/mlia/devices')
-rw-r--r--src/mlia/devices/ethosu/advice_generation.py2
-rw-r--r--src/mlia/devices/ethosu/advisor.py4
2 files changed, 3 insertions, 3 deletions
diff --git a/src/mlia/devices/ethosu/advice_generation.py b/src/mlia/devices/ethosu/advice_generation.py
index dee1650..8a38d2c 100644
--- a/src/mlia/devices/ethosu/advice_generation.py
+++ b/src/mlia/devices/ethosu/advice_generation.py
@@ -196,7 +196,7 @@ class EthosUStaticAdviceProducer(ContextAwareAdviceProducer):
Advice(
[
"For better performance, make sure that all the operators "
- "of your final TFLite model are supported by the NPU.",
+ "of your final TensorFlow Lite model are supported by the NPU.",
]
+ self.context.action_resolver.operator_compatibility_details()
)
diff --git a/src/mlia/devices/ethosu/advisor.py b/src/mlia/devices/ethosu/advisor.py
index be58de7..2c25f6c 100644
--- a/src/mlia/devices/ethosu/advisor.py
+++ b/src/mlia/devices/ethosu/advisor.py
@@ -52,10 +52,10 @@ class EthosUInferenceAdvisor(DefaultInferenceAdvisor):
# Performance and optimization are mutually exclusive.
# Decide which one to use (taking into account the model format).
if is_tflite_model(model):
# TFLite models do not support optimization (only performance)!
if context.advice_category == AdviceCategory.OPTIMIZATION:
raise Exception(
- "Command 'optimization' is not supported for TFLite files."
+ "Command 'optimization' is not supported for TensorFlow Lite files."
)
if AdviceCategory.PERFORMANCE in context.advice_category:
collectors.append(EthosUPerformance(model, device, backends))
@@ -52,10 +52,10 @@ class EthosUInferenceAdvisor(DefaultInferenceAdvisor):
# Decide which one to use (taking into account the model format).
if is_tflite_model(model):
- # TFLite models do not support optimization (only performance)!
+ # TensorFlow Lite models do not support optimization (only performance)!
if context.advice_category == AdviceCategory.OPTIMIZATION:
raise Exception(